pub struct CommandResponseTraitMethod<'a> {
pub command: &'a RecordType,
pub response: &'a DiscriminatedUnionType,
pub shapes: &'a [RecordType],
}Expand description
Generates the provided trait method for the ClientApi trait.
The ClientApi trait definition itself must be generated by the client and should look like this
ⓘ
pub trait ClientApi {
type Error;
fn send_raw(&self, command: String) -> impl Future<Output = Result<Arc<{}>, Self::Error>> + Send;
//..
}Then the provided methods could be inserted.
For methods that return multiple kinds a valid responses the additional wrapper type should be
generated. You can get this type definition using the
[CommandResponseTraitMethod::response_wrapper] method.
Fields
command: &'a RecordTyperesponse: &'a DiscriminatedUnionTypeshapes: &'a [RecordType]Implementations
Sourceimpl<'a> CommandResponseTraitMethod<'a>
impl<'a> CommandResponseTraitMethod<'a>
pub fn new( command: &'a RecordType, response: &'a DiscriminatedUnionType, shapes: &'a [RecordType], ) -> Self