pub trait Interpretable {
// Required method
fn command_syntax_impl(&self) -> Result<Option<String>, String>;
}Expand description
Represents a type with a syntax that can be interpreted as a SimpleX command. The impl should return Ok(None) when the syntax string is empty or return full implementation of the following trait:
ⓘ
trait CommandSyntax {
fn interpret(&self) -> String;
}The trait definition itself must be generated by the client manually somewhere
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".